# iOS-specific information

The Glean Swift SDK can be used in iOS applications.
The integration into the build system for iOS applications can be tuned to your needs.
See the following chapters for details.
